==> igniteui-react-charts-18.3.2-beta.0.tgz: package/esm5/lib/CategoryDateTimeXAxis_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TimeAxisBase } from "./TimeAxisBase";
import { TimeAxisDisplayType_$type } from "./TimeAxisDisplayType";
import { DependencyProperty } from "igniteui-react-core";
import { Base, enumGetBox, Number_$type, typeGetValue, typeCast, markType, markDep } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { NumericYAxis } from "./NumericYAxis";
import { LinearNumericSnapper } from "./LinearNumericSnapper";
import { LabelPosition } from "./LabelPosition";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, intDivide, isNaN_, isInfinity } from "igniteui-react-core";
import { dateMinValue, dateFromTicks } from "igniteui-react-core";
import { timeSpanFromMilliseconds } from "igniteui-react-core";
import { CategoryAxisBaseView } from "./CategoryAxisBaseView";
import { AxisDefaults } from "./AxisDefaults";
/**
 * @hidden
 */
var CategoryDateTimeXAxis = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryDateTimeXAxis, _super);
    function CategoryDateTimeXAxis() {
        var _this = _super.call(this) || this;
        _this.nt = 0;
        _this.nu = 0;
        _this.ab = CategoryDateTimeXAxis.$;
        _this.actualMinimumValue = (new Date());
        _this.actualMaximumValue = (new Date());
        return _this;
    }
    CategoryDateTimeXAxis.prototype.get_cd = function () {
        return this.no == 0;
    };
    CategoryDateTimeXAxis.prototype.a4 = function () {
        return new CategoryDateTimeXAxisView(this);
    };
    CategoryDateTimeXAxis.prototype.hs = function (a) {
        _super.prototype.hs.call(this, a);
        this.nn = a;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "nv", {
        get: function () {
            return this.nt;
        },
        set: function (a) {
            if (this.nv != a) {
                var b = this.nt;
                this.nt = a;
                this.h2("ActualInterval", b, this.nv);
            }
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.ev = function () {
        return this.nv;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "nz", {
        get: function () {
            return typeGetValue(this.c(CategoryDateTimeXAxis.oa));
        },
        set: function (a) {
            this.h(CategoryDateTimeXAxis.oa, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "nw", {
        get: function () {
            return this.nu;
        },
        set: function (a) {
            if (this.nw != a) {
                var b = this.nu;
                this.nu = a;
                this.h2("ActualMinorInterval", b, this.nw);
            }
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.c8 = function (a, b, c) {
        var d = _super.prototype.c8.call(this, a, b, c);
        if (!d) {
            return false;
        }
        return +(this.actualMinimumValue) != +(this.actualMaximumValue);
    };
    CategoryDateTimeXAxis.prototype.d4 = function () {
        return this.nv;
    };
    CategoryDateTimeXAxis.prototype.h9 = function (a) {
        _super.prototype.h9.call(this, a);
        var b = this.bi != null ? this.bi.tj : Rect.empty;
        var c = !b.isEmpty ? this.kd : Rect.empty;
        var d = this.j8();
        var e = this.j7();
        var f = new ScalerParams(0, b, c, this.ch, d);
        if ((this.mh == null || this.mh.count < 1) && !this.mn() && !this.mo()) {
            return;
        }
        if (!b.isEmpty && !c.isEmpty && (this.no != 1 || this.mh != null)) {
            var g = c.bottom;
            var h = g - c.top;
            if (this.aj != null) {
                var i = typeCast(NumericYAxis.$, this.aj);
                if (i != null) {
                    var j = this.ie(g, h, b, c, d, c.top, c.bottom);
                    g = j.p0;
                    h = j.p1;
                }
            }
            if (isNaN_(g)) {
                g = 0;
            }
            this.hq(this.a5.a1(), g, c, this.a5.e(), true);
            this.aw.bg = h;
            var k = this.a5.a4();
            var l = this.a5.f();
            var m = this.a5.a2();
            var n = this.a5.a3();
            var o = this.a5.g();
            if (this.no == 1) {
                var p = this.i$e(b, c, d, e);
                var q = this.i$g(b, c, d, e);
                if (p < 0 || q < 0) {
                    return;
                }
                var r = NaN;
                for (var s = p; s <= q; s++) {
                    var t = this.mq == null ? s : this.mq._inner[s];
                    var u = this.ej(this.mh.item(t).getTime(), f);
                    if (u == r) {
                        continue;
                    }
                    r = u;
                    if (this.categoryMode == 2) {
                        u += this.ch ? -this.getGroupCenter(s, b, c, d) : this.getGroupCenter(s, b, c, d);
                    }
                    if (u < e.left || u > e.right) {
                        continue;
                    }
                    this.im(m, u, c, l, false);
                    this.ky.add(u);
                    if (this.kr != null && s < this.kr.count) {
                        var v = this.kr.item(t);
                        var w = _super.prototype.fz.call(this, v);
                        if (!isNaN_(u) && !isInfinity(u) && w != null) {
                            if ((typeof w === 'string') && Base.equalsStatic(w, "")) {
                            }
                            else {
                                this.dc.add1(w);
                                this.dd.add(new LabelPosition(u));
                            }
                        }
                    }
                }
            }
            else {
                var x = this.em(e.left, f);
                var y = this.em(e.right, f);
                var z = Math.min(x, y);
                var aa = Math.max(x, y);
                var ab = new LinearNumericSnapper(0, z, aa, e.width, this.ey());
                var ac = this.ml ? this.ns() : ab.g;
                this.n6(truncate(ac));
                var ad = truncate(Math.floor((z - this.actualMinimumValue.getTime()) / ac));
                var ae = truncate(Math.ceil((aa - this.actualMinimumValue.getTime()) / ac));
                var af = 0;
                if (this.categoryMode == 2) {
                    af = this.getGroupCenter(0, b, c, d);
                    af = this.ch ? -af : af;
                }
                var ag = truncate(Math.ceil(e.right));
                var ah = truncate(Math.floor(e.left));
                var ai = this.ej(this.actualMinimumValue.getTime() + ad * ac, f) + af;
                for (var aj = ad; aj <= ae; aj++) {
                    var ak = this.ej(this.actualMinimumValue.getTime() + (aj + 1) * ac, f) + af;
                    if (!isNaN_(ai) && !isInfinity(ai)) {
                        var al = truncate(Math.round(ai));
                        if (al <= ag) {
                            if (aj % 2 == 0) {
                                this.io(k, ai, ak, c);
                            }
                            this.im(m, ai, c, l, false);
                            this.ky.add(ai);
                            if (this.cy) {
                                var am = this.nx();
                                if (am > 0 && am < ac) {
                                    if (ac / am < 20) {
                                        var an = ai;
                                        var ao = Math.abs(this.ej(this.actualMinimumValue.getTime() + am, f) - this.ej(this.actualMinimumValue.getTime(), f));
                                        while (an + ao < ak) {
                                            if (Math.abs(an + ao - ak) < 0.0001) {
                                                break;
                                            }
                                            an += ao;
                                            if (an > 0) {
                                                this.im(n, an, c, o, false);
                                            }
                                        }
                                        this.n7(am);
                                    }
                                }
                                else {
                                    for (var ap = 1; ap < ab.i; ++ap) {
                                        var aq = this.ej(this.actualMinimumValue.getTime() + aj * ac + (ap * ac) / ab.i, f) + af;
                                        this.im(n, aq, c, o, false);
                                    }
                                    if (ab.i > 0) {
                                        this.n7(truncate((ac / ab.i)));
                                    }
                                }
                            }
                        }
                        if (al >= ah && al <= ag) {
                            var ar = this.actualMinimumValue.getTime() + aj * ac;
                            var ticks_ = truncate(Math.floor(ar));
                            var as = (new Date(ticks_));
                            var at = this.fz(as);
                            if (at != null) {
                                this.dc.add1(at);
                                this.dd.add(new LabelPosition(ai));
                            }
                        }
                    }
                    ai = ak;
                }
            }
            if ((this.az == null || this.az.visibility == 0) && this.aj != null) {
                if (this.az != null && (this.az.location == 4 || this.az.location == 5)) {
                    this.bi.md();
                }
            }
            this.aw.a9 = this.dc;
            this.aw.ba = this.dd;
            this.l4();
        }
    };
    CategoryDateTimeXAxis.prototype.ns = function () {
        return this.nv;
    };
    CategoryDateTimeXAxis.prototype.nx = function () {
        return this.nz;
    };
    CategoryDateTimeXAxis.prototype.n6 = function (a) {
        this.nv = a;
    };
    CategoryDateTimeXAxis.prototype.n7 = function (a) {
        this.nw = a;
    };
    CategoryDateTimeXAxis.prototype.nq = function () {
        return this.ny != 0;
    };
    CategoryDateTimeXAxis.prototype.np = function () {
        return this.nv == 0;
    };
    CategoryDateTimeXAxis.prototype.nr = function (a) {
        return this.mh == null ? dateMinValue() : this.mh.item(a);
    };
    CategoryDateTimeXAxis.prototype.n5 = function (a, b) {
        if (a > b || this.kr == null || this.kr.count == 0) {
            return;
        }
        var c = (a.getTime() - this.actualMinimumValue.getTime()) / (this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
        var d = (b.getTime() - this.actualMinimumValue.getTime()) / (this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
        this.bi.tz = new Rect(0, c, this.bi.tz.y, d - c, this.bi.tz.height);
    };
    CategoryDateTimeXAxis.prototype.hw = function (a, b, c, d) {
        _super.prototype.hw.call(this, a, b, c, d);
        switch (b) {
            case CategoryDateTimeXAxis.$$p[0]:
                this.cq = true;
                this.aw.al = this.no == 1;
                this.h8(false);
                break;
            case CategoryDateTimeXAxis.$$p[1]:
                this.cq = true;
                this.h8(false);
                break;
        }
    };
    CategoryDateTimeXAxis.prototype.nd = function () {
        _super.prototype.nd.call(this);
        if (this.nq()) {
            this.nv = this.ny;
            var a = this.bi != null ? this.bi.tj : Rect.empty;
            var b = !a.isEmpty ? this.kd : Rect.empty;
            var c = Math.abs(this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
            this.ml = this.np() || (this.no == 1) || (1 * c / this.ns() > (b.width / a.width)) ? false : true;
        }
        else {
            this.ml = false;
        }
    };
    CategoryDateTimeXAxis.prototype.nb = function (a, b) {
        var c = b.getTime() - a.getTime();
        var timeOffset_ = truncate(Math.round(intDivide(c, this.lf) / 2));
        return timeOffset_ == 0 ? timeSpanFromMilliseconds(1) : timeSpanFromMilliseconds(timeOffset_);
    };
    CategoryDateTimeXAxis.prototype.get_cc = function () {
        return true;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "isVertical", {
        get: function () {
            return this.cp;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.j$d = function (a, b) {
        return this.em.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$c = function (a, b) {
        return this.ej.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$e = function (a, b, c, d, e) {
        this.hm.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$f = function (a, b, c, d) {
        this.hn.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$g = function (a, b, c, d) {
        this.ho.apply(this, arguments);
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "j$b", {
        get: function () {
            return this.ch;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.j$a = function () {
        return this.ag.apply(this, arguments);
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "i$a", {
        get: function () {
            return this.ce;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.$t = markType(CategoryDateTimeXAxis, 'CategoryDateTimeXAxis', TimeAxisBase.$);
    CategoryDateTimeXAxis.oa = DependencyProperty.i("MinorInterval", Number_$type, CategoryDateTimeXAxis.$, new PropertyMetadata(2, 0, function (a, b) {
        (typeCast(CategoryDateTimeXAxis.$, a)).h2("MinorInterval", b.oldValue, b.newValue);
        (typeCast(CategoryDateTimeXAxis.$, a)).h8(false);
    }));
    CategoryDateTimeXAxis.$$p = markDep(DependencyProperty, PropertyMetadata, CategoryDateTimeXAxis, 'h2', ['DisplayType:no:n8', [TimeAxisDisplayType_$type, enumGetBox(TimeAxisDisplayType_$type, 0)], 'Interval:ny:n9', [1, 0]]);
    return CategoryDateTimeXAxis;
}(TimeAxisBase));
export { CategoryDateTimeXAxis };
/**
 * @hidden
 */
var CategoryDateTimeXAxisView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryDateTimeXAxisView, _super);
    function CategoryDateTimeXAxisView(a) {
        var _this = _super.call(this, a) || this;
        _this.bj = null;
        _this.bj = a;
        return _this;
    }
    CategoryDateTimeXAxisView.prototype.aj = function () {
        _super.prototype.aj.call(this);
        this.a.fh = AxisDefaults.f;
    };
    CategoryDateTimeXAxisView.prototype.r = function (a) {
        var b = this.p(dateFromTicks(truncate(a)));
        return b;
    };
    CategoryDateTimeXAxisView.$t = markType(CategoryDateTimeXAxisView, 'CategoryDateTimeXAxisView', CategoryAxisBaseView.$);
    return CategoryDateTimeXAxisView;
}(CategoryAxisBaseView));
export { CategoryDateTimeXAxisView };

==> igniteui-react-charts-18.6.1-beta.0.tgz: package/esm5/lib/CategoryDateTimeXAxis_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { TimeAxisBase } from "./TimeAxisBase";
import { DependencyProperty } from "igniteui-react-core";
import { TimeAxisDisplayType_$type } from "./TimeAxisDisplayType";
import { Base, enumGetBox, Number_$type, typeGetValue, typeCast, markType, markDep } from "igniteui-react-core";
import { Rect } from "igniteui-react-core";
import { ScalerParams } from "./ScalerParams";
import { NumericYAxis } from "./NumericYAxis";
import { LinearNumericSnapper } from "./LinearNumericSnapper";
import { LabelPosition } from "./LabelPosition";
import { PropertyMetadata } from "igniteui-react-core";
import { truncate, intDivide, isNaN_, isInfinity } from "igniteui-react-core";
import { dateMinValue, dateFromTicks } from "igniteui-react-core";
import { timeSpanFromMilliseconds } from "igniteui-react-core";
import { CategoryAxisBaseView } from "./CategoryAxisBaseView";
import { AxisDefaults } from "./AxisDefaults";
/**
 * @hidden
 */
var CategoryDateTimeXAxis = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryDateTimeXAxis, _super);
    function CategoryDateTimeXAxis() {
        var _this = _super.call(this) || this;
        _this.nu = 0;
        _this.nv = 0;
        _this.ab = CategoryDateTimeXAxis.$;
        _this.actualMinimumValue = (new Date());
        _this.actualMaximumValue = (new Date());
        return _this;
    }
    CategoryDateTimeXAxis.prototype.get_cd = function () {
        return this.no == 0;
    };
    CategoryDateTimeXAxis.prototype.a4 = function () {
        return new CategoryDateTimeXAxisView(this);
    };
    CategoryDateTimeXAxis.prototype.hs = function (a) {
        _super.prototype.hs.call(this, a);
        this.nn = a;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "nw", {
        get: function () {
            return this.nu;
        },
        set: function (a) {
            if (this.nw != a) {
                var b = this.nu;
                this.nu = a;
                this.h2("ActualInterval", b, this.nw);
            }
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.ev = function () {
        return this.nw;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "n0", {
        get: function () {
            return typeGetValue(this.c(CategoryDateTimeXAxis.oc));
        },
        set: function (a) {
            this.h(CategoryDateTimeXAxis.oc, a);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "nx", {
        get: function () {
            return this.nv;
        },
        set: function (a) {
            if (this.nx != a) {
                var b = this.nv;
                this.nv = a;
                this.h2("ActualMinorInterval", b, this.nx);
            }
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.c8 = function (a, b, c) {
        var d = _super.prototype.c8.call(this, a, b, c);
        if (!d) {
            return false;
        }
        return +(this.actualMinimumValue) != +(this.actualMaximumValue);
    };
    CategoryDateTimeXAxis.prototype.d4 = function () {
        return this.nw;
    };
    CategoryDateTimeXAxis.prototype.h9 = function (a) {
        _super.prototype.h9.call(this, a);
        var b = this.bi != null ? this.bi.vh : Rect.empty;
        var c = !b.isEmpty ? this.kd : Rect.empty;
        var d = this.j8();
        var e = this.j7();
        var f = new ScalerParams(0, b, c, this.ch, d);
        if ((this.mh == null || this.mh.count < 1) && !this.mn() && !this.mo()) {
            return;
        }
        if (!b.isEmpty && !c.isEmpty && (this.no != 1 || this.mh != null)) {
            var g = c.bottom;
            var h = g - c.top;
            if (this.aj != null) {
                var i = typeCast(NumericYAxis.$, this.aj);
                if (i != null) {
                    var j = this.ie(g, h, b, c, d, c.top, c.bottom);
                    g = j.p0;
                    h = j.p1;
                }
            }
            if (isNaN_(g)) {
                g = 0;
            }
            this.hq(this.a5.a4(), g, c, this.a5.e(), true);
            this.aw.bg = h;
            var k = this.a5.a7();
            var l = this.a5.f();
            var m = this.a5.a5();
            var n = this.a5.a6();
            var o = this.a5.g();
            if (this.no == 1) {
                var p = this.i$e(b, c, d, e);
                var q = this.i$g(b, c, d, e);
                if (p < 0 || q < 0) {
                    return;
                }
                var r = NaN;
                for (var s = p; s <= q; s++) {
                    var t = this.mq == null ? s : this.mq._inner[s];
                    var u = this.ej(this.mh.item(t).getTime(), f);
                    if (u == r) {
                        continue;
                    }
                    r = u;
                    if (this.categoryMode == 2) {
                        u += this.ch ? -this.getGroupCenter(s, b, c, d) : this.getGroupCenter(s, b, c, d);
                    }
                    if (u < e.left || u > e.right) {
                        continue;
                    }
                    this.im(m, u, c, l, false);
                    this.ky.add(u);
                    if (this.kr != null && s < this.kr.count) {
                        var v = this.kr.item(t);
                        var w = _super.prototype.fz.call(this, v);
                        if (!isNaN_(u) && !isInfinity(u) && w != null) {
                            if ((typeof w === 'string') && Base.equalsStatic(w, "")) {
                            }
                            else {
                                this.dc.add1(w);
                                this.dd.add(new LabelPosition(u));
                            }
                        }
                    }
                }
            }
            else {
                var x = this.em(e.left, f);
                var y = this.em(e.right, f);
                var z = Math.min(x, y);
                var aa = Math.max(x, y);
                var ab = new LinearNumericSnapper(0, z, aa, e.width, this.ey());
                var ac = this.ml ? this.nt() : ab.g;
                this.n8(truncate(ac));
                var ad = truncate(Math.floor((z - this.actualMinimumValue.getTime()) / ac));
                var ae = truncate(Math.ceil((aa - this.actualMinimumValue.getTime()) / ac));
                var af = 0;
                if (this.categoryMode == 2) {
                    af = this.getGroupCenter(0, b, c, d);
                    af = this.ch ? -af : af;
                }
                var ag = truncate(Math.ceil(e.right));
                var ah = truncate(Math.floor(e.left));
                var ai = this.ej(this.actualMinimumValue.getTime() + ad * ac, f) + af;
                for (var aj = ad; aj <= ae; aj++) {
                    var ak = this.ej(this.actualMinimumValue.getTime() + (aj + 1) * ac, f) + af;
                    if (!isNaN_(ai) && !isInfinity(ai)) {
                        var al = truncate(Math.round(ai));
                        if (al <= ag) {
                            if (aj % 2 == 0) {
                                this.io(k, ai, ak, c);
                            }
                            this.im(m, ai, c, l, false);
                            this.ky.add(ai);
                            if (this.cy) {
                                var am = this.ny();
                                if (am > 0 && am < ac) {
                                    if (ac / am < 20) {
                                        var an = ai;
                                        var ao = Math.abs(this.ej(this.actualMinimumValue.getTime() + am, f) - this.ej(this.actualMinimumValue.getTime(), f));
                                        while (an + ao < ak) {
                                            if (Math.abs(an + ao - ak) < 0.0001) {
                                                break;
                                            }
                                            an += ao;
                                            if (an > 0) {
                                                this.im(n, an, c, o, false);
                                            }
                                        }
                                        this.n9(am);
                                    }
                                }
                                else {
                                    for (var ap = 1; ap < ab.i; ++ap) {
                                        var aq = this.ej(this.actualMinimumValue.getTime() + aj * ac + (ap * ac) / ab.i, f) + af;
                                        this.im(n, aq, c, o, false);
                                    }
                                    if (ab.i > 0) {
                                        this.n9(truncate((ac / ab.i)));
                                    }
                                }
                            }
                        }
                        if (al >= ah && al <= ag) {
                            var ar = this.actualMinimumValue.getTime() + aj * ac;
                            var ticks_ = truncate(Math.floor(ar));
                            var as = (new Date(ticks_));
                            var at = this.fz(as);
                            if (at != null) {
                                this.dc.add1(at);
                                this.dd.add(new LabelPosition(ai));
                            }
                        }
                    }
                    ai = ak;
                }
            }
            if ((this.az == null || this.az.visibility == 0) && this.aj != null) {
                if (this.az != null && (this.az.location == 4 || this.az.location == 5)) {
                    this.bi.nn();
                }
            }
            this.aw.a9 = this.dc;
            this.aw.ba = this.dd;
            this.l4();
        }
    };
    CategoryDateTimeXAxis.prototype.nt = function () {
        return this.nw;
    };
    CategoryDateTimeXAxis.prototype.ny = function () {
        return this.n0;
    };
    CategoryDateTimeXAxis.prototype.n8 = function (a) {
        this.nw = a;
    };
    CategoryDateTimeXAxis.prototype.n9 = function (a) {
        this.nx = a;
    };
    CategoryDateTimeXAxis.prototype.nq = function () {
        return this.nz != 0;
    };
    CategoryDateTimeXAxis.prototype.np = function () {
        return this.nw == 0;
    };
    CategoryDateTimeXAxis.prototype.ns = function (a) {
        return this.mh == null ? dateMinValue() : this.mh.item(a);
    };
    CategoryDateTimeXAxis.prototype.n7 = function (a, b) {
        if (a > b || this.kr == null || this.kr.count == 0) {
            return;
        }
        var c = (a.getTime() - this.actualMinimumValue.getTime()) / (this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
        var d = (b.getTime() - this.actualMinimumValue.getTime()) / (this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
        this.bi.vx = new Rect(0, c, this.bi.vx.y, d - c, this.bi.vx.height);
    };
    CategoryDateTimeXAxis.prototype.hw = function (a, b, c, d) {
        _super.prototype.hw.call(this, a, b, c, d);
        switch (b) {
            case CategoryDateTimeXAxis.$$p[0]:
                this.cq = true;
                this.aw.al = this.no == 1 || this.nr;
                this.h8(false);
                break;
            case CategoryDateTimeXAxis.$$p[1]:
                this.cq = true;
                this.h8(false);
                break;
            case CategoryDateTimeXAxis.$$p[2]:
                this.aw.al = this.no == 1 || this.nr;
                break;
        }
    };
    CategoryDateTimeXAxis.prototype.nd = function () {
        _super.prototype.nd.call(this);
        if (this.nq()) {
            this.nw = this.nz;
            var a = this.bi != null ? this.bi.vh : Rect.empty;
            var b = !a.isEmpty ? this.kd : Rect.empty;
            var c = Math.abs(this.actualMaximumValue.getTime() - this.actualMinimumValue.getTime());
            this.ml = this.np() || (this.no == 1) || (1 * c / this.nt() > (b.width / a.width)) ? false : true;
        }
        else {
            this.ml = false;
        }
    };
    CategoryDateTimeXAxis.prototype.nb = function (a, b) {
        var c = b.getTime() - a.getTime();
        var timeOffset_ = truncate(Math.round(intDivide(c, this.lf) / 2));
        return timeOffset_ == 0 ? timeSpanFromMilliseconds(1) : timeSpanFromMilliseconds(timeOffset_);
    };
    CategoryDateTimeXAxis.prototype.get_cc = function () {
        return true;
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "isVertical", {
        get: function () {
            return this.cp;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.j$d = function (a, b) {
        return this.em.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$c = function (a, b) {
        return this.ej.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$e = function (a, b, c, d, e) {
        this.hm.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$f = function (a, b, c, d) {
        this.hn.apply(this, arguments);
    };
    CategoryDateTimeXAxis.prototype.j$g = function (a, b, c, d) {
        this.ho.apply(this, arguments);
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "j$b", {
        get: function () {
            return this.ch;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.prototype.j$a = function () {
        return this.ag.apply(this, arguments);
    };
    Object.defineProperty(CategoryDateTimeXAxis.prototype, "i$a", {
        get: function () {
            return this.ce;
        },
        enumerable: false,
        configurable: true
    });
    CategoryDateTimeXAxis.$t = markType(CategoryDateTimeXAxis, 'CategoryDateTimeXAxis', TimeAxisBase.$);
    CategoryDateTimeXAxis.oc = DependencyProperty.i("MinorInterval", Number_$type, CategoryDateTimeXAxis.$, new PropertyMetadata(2, 0, function (a, b) {
        (typeCast(CategoryDateTimeXAxis.$, a)).h2("MinorInterval", b.oldValue, b.newValue);
        (typeCast(CategoryDateTimeXAxis.$, a)).h8(false);
    }));
    CategoryDateTimeXAxis.$$p = markDep(DependencyProperty, PropertyMetadata, CategoryDateTimeXAxis, 'h2', ['DisplayType:no:oa', [TimeAxisDisplayType_$type, enumGetBox(TimeAxisDisplayType_$type, 0)], 'Interval:nz:ob', [1, 0], 'UnevenlySpacedLabels:nr:od', [0, false]]);
    return CategoryDateTimeXAxis;
}(TimeAxisBase));
export { CategoryDateTimeXAxis };
/**
 * @hidden
 */
var CategoryDateTimeXAxisView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryDateTimeXAxisView, _super);
    function CategoryDateTimeXAxisView(a) {
        var _this = _super.call(this, a) || this;
        _this.bm = null;
        _this.bm = a;
        return _this;
    }
    CategoryDateTimeXAxisView.prototype.al = function () {
        _super.prototype.al.call(this);
        this.a.fh = AxisDefaults.f;
    };
    CategoryDateTimeXAxisView.prototype.s = function (a) {
        var b = this.q(dateFromTicks(truncate(a)));
        return b;
    };
    CategoryDateTimeXAxisView.$t = markType(CategoryDateTimeXAxisView, 'CategoryDateTimeXAxisView', CategoryAxisBaseView.$);
    return CategoryDateTimeXAxisView;
}(CategoryAxisBaseView));
export { CategoryDateTimeXAxisView };
